vaccination
====

A program to show the effectiveness of vaccination with symptoms by age groups

##Description
This program reads the data from CSV file (https://data.cdc.gov/api/views/3rge-nu2a/rows.csv) and then, calculates the rate of the outcome with vaccinated and unvaccinated for each age group

##Demo
The following grapgh is an example of all ages.
![effectiveness_all_ages_adj_case](https://github.com/Ryumi-Ryumi/vaccination/assets/153894701/07ba7dae-22ff-4bac-bf19-d5400d3b1c9a)
![effectiveness_all_ages_adj_death](https://github.com/Ryumi-Ryumi/vaccination/assets/153894701/ca0b841b-99f5-4f39-bef7-d62613747efa)

##Usage
Create a file 'vaccination.py' in your directory and paste the code on your file 'vaccination.py'
Then, run the file

##Author
Ryumi Ryumi
